@@ -18,19 +18,19 @@
  */
 package org.apache.parquet.column.values.bytestreamsplit;
 
+import java.io.IOException;
+import java.nio.ByteBuffer;
+import java.nio.ByteOrder;
 import org.apache.parquet.bytes.ByteBufferInputStream;
 import org.apache.parquet.column.values.ValuesReader;
 import org.apache.parquet.io.ParquetDecodingException;
-
-import java.io.IOException;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
 public abstract class ByteStreamSplitValuesReader extends ValuesReader {
-
   private static final Logger LOG = LoggerFactory.getLogger(ByteStreamSplitValuesReader.class);
-  private final int elementSizeInBytes;
-  private byte[] byteStreamData;
+  protected final int elementSizeInBytes;
+  protected ByteBuffer decodedDataBuffer;
   private int indexInStream;
   private int valuesCount;
 
@@ -40,22 +40,32 @@ public abstract class ByteStreamSplitValuesReader extends ValuesReader {
     this.valuesCount = 0;
   }
 
-  protected void gatherElementDataFromStreams(byte[] gatheredData)
-          throws ParquetDecodingException {
-    if (gatheredData.length != elementSizeInBytes) {
-      throw new ParquetDecodingException("gatherData buffer is not of the expected size.");
-    }
+  protected int nextElementByteOffset() {
     if (indexInStream >= valuesCount) {
       throw new ParquetDecodingException("Byte-stream data was already exhausted.");
     }
-    for (int i = 0; i < elementSizeInBytes; ++i) {
-      gatheredData[i] = byteStreamData[i * valuesCount + indexInStream];
-    }
+    int offset = indexInStream * elementSizeInBytes;
     ++indexInStream;
+    return offset;
+  }
+
+  // Decode an entire data page
+  private byte[] decodeData(ByteBuffer encoded, int valuesCount) {
+    assert encoded.limit() == valuesCount * elementSizeInBytes;
+    byte[] decoded = new byte[encoded.limit()];
+    int destByteIndex = 0;
+    for (int srcValueIndex = 0; srcValueIndex < valuesCount; ++srcValueIndex) {
+      for (int stream = 0; stream < elementSizeInBytes; ++stream, ++destByteIndex) {
+        decoded[destByteIndex] = encoded.get(srcValueIndex + stream * valuesCount);
+      }
+    }
+    assert destByteIndex == decoded.length;
+    return decoded;
   }
 
   @Override
-  public void initFromPage(int valuesCount, ByteBufferInputStream stream) throws ParquetDecodingException, IOException {
+  public void initFromPage(int valuesCount, ByteBufferInputStream stream)
+      throws ParquetDecodingException, IOException {
     LOG.debug("init from page at offset {} for length {}", stream.position(), stream.available());
 
     // ByteStreamSplitValuesWriter does not write number of encoded values to the stream. As the parquet
@@ -63,8 +73,8 @@ public abstract class ByteStreamSplitValuesReader extends ValuesReader {
     // by dividing the number of bytes in the stream by the size of each element.
     if (stream.available() % elementSizeInBytes != 0) {
       String errorMessage = String.format(
-              "Invalid ByteStreamSplit stream, total length: %d bytes, element size: %d bytes.",
-              stream.available(), elementSizeInBytes);
+          "Invalid ByteStreamSplit stream, total length: %d bytes, element size: %d bytes.",
+          stream.available(), elementSizeInBytes);
       throw new ParquetDecodingException(errorMessage);
     }
     this.valuesCount = stream.available() / elementSizeInBytes;
@@ -72,23 +82,17 @@ public abstract class ByteStreamSplitValuesReader extends ValuesReader {
     // The input valuesCount includes number of nulls. It is used for an upperbound check only.
     if (valuesCount < this.valuesCount) {
       String errorMessage = String.format(
-              "Invalid ByteStreamSplit stream, num values upper bound (w/ nulls): %d, num encoded values: %d",
-              valuesCount, this.valuesCount);
+          "Invalid ByteStreamSplit stream, num values upper bound (w/ nulls): %d, num encoded values: %d",
+          valuesCount, this.valuesCount);
       throw new ParquetDecodingException(errorMessage);
     }
 
-    // Allocate buffer for all of the byte stream data.
+    // Eagerly read and decode the data. This allows returning stable
+    // Binary views into the internal decode buffer for FIXED_LEN_BYTE_ARRAY.
     final int totalSizeInBytes = stream.available();
-    byteStreamData = new byte[totalSizeInBytes];
-
-    // Eagerly read the data for each stream.
-    final int numRead = stream.read(byteStreamData, 0, totalSizeInBytes);
-    if (numRead != totalSizeInBytes) {
-      String errorMessage = String.format("Failed to read requested number of bytes. Expected: %d. Read %d.",
-              totalSizeInBytes, numRead);
-      throw new ParquetDecodingException(errorMessage);
-    }
-
+    final ByteBuffer encodedData = stream.slice(totalSizeInBytes).slice(); // possibly zero-copy
+    final byte[] decodedData = decodeData(encodedData, this.valuesCount);
+    decodedDataBuffer = ByteBuffer.wrap(decodedData).order(ByteOrder.LITTLE_ENDIAN);
     indexInStream = 0;
   }
 
@@ -101,11 +105,10 @@ public abstract class ByteStreamSplitValuesReader extends ValuesReader {
   public void skip(int n) {
     if (n < 0 || indexInStream + n > valuesCount) {
       String errorMessage = String.format(
-              "Cannot skip this many elements. Current index: %d. Skip %d. Total number of elements: %d",
-              indexInStream, n, valuesCount);
+          "Cannot skip this many elements. Current index: %d. Skip %d. Total number of elements: %d",
+          indexInStream, n, valuesCount);
       throw new ParquetDecodingException(errorMessage);
     }
     indexInStream += n;
   }
-
 }
