@@ -24,6 +24,8 @@ import java.io.Serializable;
 import java.util.Locale;
 import java.util.Objects;
 import java.util.Set;
+import java.util.function.BiFunction;
+import java.util.function.Function;
 import org.apache.parquet.hadoop.metadata.ColumnPath;
 import org.apache.parquet.io.api.Binary;
 
@@ -120,8 +122,13 @@ public final class Operators {
     }
   }
 
+  abstract static class SingleColumnFilterPredicate<T extends Comparable<T>>
+      implements FilterPredicate, Serializable {
+    abstract Column<T> getColumn();
+  }
+
   // base class for Eq, NotEq, Lt, Gt, LtEq, GtEq
-  abstract static class ColumnFilterPredicate<T extends Comparable<T>> implements FilterPredicate, Serializable {
+  abstract static class ColumnFilterPredicate<T extends Comparable<T>> extends SingleColumnFilterPredicate<T> {
     private final Column<T> column;
     private final T value;
 
@@ -133,6 +140,7 @@ public final class Operators {
       this.value = value;
     }
 
+    @Override
     public Column<T> getColumn() {
       return column;
     }
@@ -252,7 +260,7 @@ public final class Operators {
    * {@link NotIn} is used to filter data that are not in the list of values.
    */
   public abstract static class SetColumnFilterPredicate<T extends Comparable<T>>
-      implements FilterPredicate, Serializable {
+      extends SingleColumnFilterPredicate<T> {
     private final Column<T> column;
     private final Set<T> values;
 
@@ -262,6 +270,7 @@ public final class Operators {
       checkArgument(!values.isEmpty(), "values in SetColumnFilterPredicate shouldn't be empty!");
     }
 
+    @Override
     public Column<T> getColumn() {
       return column;
     }
@@ -315,6 +324,187 @@ public final class Operators {
     }
   }
 
+  private static class DoesNotContain<T extends Comparable<T>> extends Contains<T> {
+    Contains<T> underlying;
+
+    protected DoesNotContain(Contains<T> underlying) {
+      super(underlying.getColumn());
+      this.underlying = underlying;
+    }
+
+    @Override
+    public <R> R accept(Visitor<R> visitor) {
+      return visitor.visit(this);
+    }
+
+    @Override
+    public <R> R filter(
+        Visitor<R> visitor,
+        BiFunction<R, R, R> andBehavior,
+        BiFunction<R, R, R> orBehavior,
+        Function<R, R> notBehavior) {
+      return notBehavior.apply(visitor.visit(underlying));
+    }
+
+    @Override
+    public String toString() {
+      return "not(" + underlying.toString() + ")";
+    }
+  }
+
+  public abstract static class Contains<T extends Comparable<T>> implements FilterPredicate, Serializable {
+    private final Column<T> column;
+
+    protected Contains(Column<T> column) {
+      this.column = Objects.requireNonNull(column, "column cannot be null");
+    }
+
+    static <ColumnT extends Comparable<ColumnT>, C extends SingleColumnFilterPredicate<ColumnT>>
+        Contains<ColumnT> of(C pred) {
+      return new ContainsColumnPredicate<>(pred);
+    }
+
+    public Column<T> getColumn() {
+      return column;
+    }
+
+    @Override
+    public <R> R accept(Visitor<R> visitor) {
+      return visitor.visit(this);
+    }
+
+    /**
+     * Applies a filtering Visitor to the Contains predicate, traversing any composed And or Or clauses,
+     * and finally delegating to the underlying column predicate.
+     */
+    public abstract <R> R filter(
+        Visitor<R> visitor,
+        BiFunction<R, R, R> andBehavior,
+        BiFunction<R, R, R> orBehavior,
+        Function<R, R> notBehavior);
+
+    Contains<T> and(FilterPredicate other) {
+      return new ContainsComposedPredicate<>(this, (Contains<T>) other, ContainsComposedPredicate.Combinator.AND);
+    }
+
+    Contains<T> or(FilterPredicate other) {
+      return new ContainsComposedPredicate<>(this, (Contains<T>) other, ContainsComposedPredicate.Combinator.OR);
+    }
+
+    Contains<T> not() {
+      return new DoesNotContain<>(this);
+    }
+  }
+
+  private static class ContainsComposedPredicate<T extends Comparable<T>> extends Contains<T> {
+    private final Contains<T> left;
+    private final Contains<T> right;
+
+    private final Combinator combinator;
+
+    private enum Combinator {
+      AND,
+      OR
+    }
+
+    ContainsComposedPredicate(Contains<T> left, Contains<T> right, Combinator combinator) {
+      super(Objects.requireNonNull(left, "left predicate cannot be null").getColumn());
+
+      if (!left.getColumn()
+          .columnPath
+          .equals(Objects.requireNonNull(right, "right predicate cannot be null")
+              .getColumn()
+              .columnPath)) {
+        throw new IllegalArgumentException("Composed Contains predicates must reference the same column name; "
+            + "found [" + left.getColumn().columnPath.toDotString() + ", "
+            + right.getColumn().columnPath.toDotString() + "]");
+      }
+
+      this.left = left;
+      this.right = right;
+      this.combinator = combinator;
+    }
+
+    @Override
+    public <R> R filter(
+        Visitor<R> visitor,
+        BiFunction<R, R, R> andBehavior,
+        BiFunction<R, R, R> orBehavior,
+        Function<R, R> notBehavior) {
+      final R filterLeft = left.filter(visitor, andBehavior, orBehavior, notBehavior);
+      final R filterRight = right.filter(visitor, andBehavior, orBehavior, notBehavior);
+
+      if (combinator == Combinator.AND) {
+        return andBehavior.apply(filterLeft, filterRight);
+      } else {
+        return orBehavior.apply(filterLeft, filterRight);
+      }
+    }
+
+    @Override
+    public String toString() {
+      return combinator.toString().toLowerCase() + "(" + left + ", " + right + ")";
+    }
+
+    @Override
+    public boolean equals(Object o) {
+      if (this == o) return true;
+      if (o == null || getClass() != o.getClass()) return false;
+      ContainsComposedPredicate<T> that = (ContainsComposedPredicate<T>) o;
+      return left.equals(that.left) && right.equals(that.right);
+    }
+
+    @Override
+    public int hashCode() {
+      return Objects.hash(getClass().getName(), left, right);
+    }
+  }
+
+  private static class ContainsColumnPredicate<T extends Comparable<T>, U extends SingleColumnFilterPredicate<T>>
+      extends Contains<T> {
+    private final U underlying;
+
+    ContainsColumnPredicate(U underlying) {
+      super(underlying.getColumn());
+      if ((underlying instanceof ColumnFilterPredicate && ((ColumnFilterPredicate) underlying).getValue() == null)
+          || (underlying instanceof SetColumnFilterPredicate
+              && ((SetColumnFilterPredicate) underlying)
+                  .getValues()
+                  .contains(null))) {
+        throw new IllegalArgumentException("Contains predicate does not support null element value(s)");
+      }
+      this.underlying = underlying;
+    }
+
+    @Override
+    public String toString() {
+      String name = Contains.class.getSimpleName().toLowerCase(Locale.ENGLISH);
+      return name + "(" + underlying.toString() + ")";
+    }
+
+    @Override
+    public boolean equals(Object o) {
+      if (this == o) return true;
+      if (o == null || getClass() != o.getClass()) return false;
+      ContainsColumnPredicate<T, U> that = (ContainsColumnPredicate<T, U>) o;
+      return underlying.equals(that.underlying);
+    }
+
+    @Override
+    public int hashCode() {
+      return Objects.hash(getClass().getName(), underlying);
+    }
+
+    @Override
+    public <R> R filter(
+        Visitor<R> visitor,
+        BiFunction<R, R, R> andBehavior,
+        BiFunction<R, R, R> orBehavior,
+        Function<R, R> notBehavior) {
+      return underlying.accept(visitor);
+    }
+  }
+
   public static final class NotIn<T extends Comparable<T>> extends SetColumnFilterPredicate<T> {
 
     NotIn(Column<T> column, Set<T> values) {
