@@ -24,7 +24,6 @@ import java.util.ArrayDeque;
 import java.util.Arrays;
 import java.util.Deque;
 import java.util.List;
-
 import org.apache.parquet.io.api.Binary;
 import org.apache.parquet.io.api.Converter;
 import org.apache.parquet.io.api.GroupConverter;
@@ -44,7 +43,7 @@ public class ExpectationValidatingConverter extends RecordMaterializer<Void> {
   int count = 0;
 
   public void validate(String got) {
-    assertEquals("event #"+count, expectations.pop(), got);
+    assertEquals("event #" + count, expectations.pop(), got);
     ++count;
   }
 
@@ -54,7 +53,7 @@ public class ExpectationValidatingConverter extends RecordMaterializer<Void> {
 
   public ExpectationValidatingConverter(Deque<String> expectations, MessageType schema) {
     this.expectations = expectations;
-    this.root = (GroupConverter)schema.convertWith(new TypeConverter<Converter>() {
+    this.root = (GroupConverter) schema.convertWith(new TypeConverter<Converter>() {
 
       @Override
       public Converter convertPrimitiveType(final List<GroupType> path, final PrimitiveType primitiveType) {
@@ -66,38 +65,39 @@ public class ExpectationValidatingConverter extends RecordMaterializer<Void> {
 
           @Override
           public void addBinary(Binary value) {
-            validate("addBinary("+value.toStringUsingUTF8()+")");
+            validate("addBinary(" + value.toStringUsingUTF8() + ")");
           }
 
           @Override
           public void addBoolean(boolean value) {
-            validate("addBoolean("+value+")");
+            validate("addBoolean(" + value + ")");
           }
 
           @Override
           public void addDouble(double value) {
-            validate("addDouble("+value+")");
+            validate("addDouble(" + value + ")");
           }
 
           @Override
           public void addFloat(float value) {
-            validate("addFloat("+value+")");
+            validate("addFloat(" + value + ")");
           }
 
           @Override
           public void addInt(int value) {
-            validate("addInt("+value+")");
+            validate("addInt(" + value + ")");
           }
 
           @Override
           public void addLong(long value) {
-            validate("addLong("+value+")");
+            validate("addLong(" + value + ")");
           }
         };
       }
 
       @Override
-      public Converter convertGroupType(final List<GroupType> path, final GroupType groupType, final List<Converter> children) {
+      public Converter convertGroupType(
+          final List<GroupType> path, final GroupType groupType, final List<Converter> children) {
         return new GroupConverter() {
 
           private void validate(String message) {
@@ -118,7 +118,6 @@ public class ExpectationValidatingConverter extends RecordMaterializer<Void> {
           public Converter getConverter(int fieldIndex) {
             return children.get(fieldIndex);
           }
-
         };
       }
 
@@ -152,7 +151,7 @@ public class ExpectationValidatingConverter extends RecordMaterializer<Void> {
 
   private String path(List<GroupType> path, Type type) {
     StringBuilder pathString = new StringBuilder();
-    if (path.size() > 0) {
+    if (!path.isEmpty()) {
       for (int i = 1; i < path.size(); i++) {
         pathString.append(path.get(i).getName()).append('.');
       }
@@ -165,5 +164,4 @@ public class ExpectationValidatingConverter extends RecordMaterializer<Void> {
   public GroupConverter getRootConverter() {
     return root;
   }
-
 }
