@@ -38,19 +38,19 @@ import java.io.InputStream;
 import java.io.OutputStream;
 import java.nio.charset.StandardCharsets;
 import java.util.List;
-
-import org.apache.thrift.TBase;
-import org.apache.thrift.TException;
-import org.apache.thrift.protocol.TCompactProtocol;
-import org.apache.thrift.protocol.TProtocol;
-import org.apache.thrift.transport.TIOStreamTransport;
-import org.apache.thrift.transport.TMemoryBuffer;
 import org.apache.parquet.format.event.Consumers.Consumer;
 import org.apache.parquet.format.event.Consumers.DelegatingFieldConsumer;
 import org.apache.parquet.format.event.EventBasedThriftReader;
 import org.apache.parquet.format.event.TypedConsumer.I32Consumer;
 import org.apache.parquet.format.event.TypedConsumer.I64Consumer;
 import org.apache.parquet.format.event.TypedConsumer.StringConsumer;
+import org.apache.thrift.TBase;
+import org.apache.thrift.TException;
+import org.apache.thrift.protocol.TCompactProtocol;
+import org.apache.thrift.protocol.TProtocol;
+import org.apache.thrift.transport.TIOStreamTransport;
+import org.apache.thrift.transport.TMemoryBuffer;
+import org.apache.thrift.transport.TTransportException;
 
 /**
  * Utility to read/write metadata
@@ -58,14 +58,14 @@ import org.apache.parquet.format.event.TypedConsumer.StringConsumer;
  */
 public class Util {
 
-  private final static int INIT_MEM_ALLOC_ENCR_BUFFER = 100;
+  private static final int INIT_MEM_ALLOC_ENCR_BUFFER = 100;
 
   public static void writeColumnIndex(ColumnIndex columnIndex, OutputStream to) throws IOException {
     writeColumnIndex(columnIndex, to, null, null);
   }
 
-  public static void writeColumnIndex(ColumnIndex columnIndex, OutputStream to, 
-      BlockCipher.Encryptor encryptor, byte[] AAD) throws IOException {
+  public static void writeColumnIndex(
+      ColumnIndex columnIndex, OutputStream to, BlockCipher.Encryptor encryptor, byte[] AAD) throws IOException {
     write(columnIndex, to, encryptor, AAD);
   }
 
@@ -73,8 +73,8 @@ public class Util {
     return readColumnIndex(from, null, null);
   }
 
-  public static ColumnIndex readColumnIndex(InputStream from, 
-      BlockCipher.Decryptor decryptor, byte[] AAD) throws IOException {
+  public static ColumnIndex readColumnIndex(InputStream from, BlockCipher.Decryptor decryptor, byte[] AAD)
+      throws IOException {
     return read(from, new ColumnIndex(), decryptor, AAD);
   }
 
@@ -82,8 +82,8 @@ public class Util {
     writeOffsetIndex(offsetIndex, to, null, null);
   }
 
-  public static void writeOffsetIndex(OffsetIndex offsetIndex, OutputStream to, 
-      BlockCipher.Encryptor encryptor, byte[] AAD) throws IOException {
+  public static void writeOffsetIndex(
+      OffsetIndex offsetIndex, OutputStream to, BlockCipher.Encryptor encryptor, byte[] AAD) throws IOException {
     write(offsetIndex, to, encryptor, AAD);
   }
 
@@ -91,8 +91,8 @@ public class Util {
     return readOffsetIndex(from, null, null);
   }
 
-  public static OffsetIndex readOffsetIndex(InputStream from, 
-      BlockCipher.Decryptor decryptor, byte[] AAD) throws IOException {
+  public static OffsetIndex readOffsetIndex(InputStream from, BlockCipher.Decryptor decryptor, byte[] AAD)
+      throws IOException {
     return read(from, new OffsetIndex(), decryptor, AAD);
   }
 
@@ -103,14 +103,15 @@ public class Util {
   public static void writeBloomFilterHeader(BloomFilterHeader header, OutputStream out) throws IOException {
     writeBloomFilterHeader(header, out, null, null);
   }
-  
-  public static BloomFilterHeader readBloomFilterHeader(InputStream from,
-      BlockCipher.Decryptor decryptor, byte[] AAD) throws IOException {
+
+  public static BloomFilterHeader readBloomFilterHeader(InputStream from, BlockCipher.Decryptor decryptor, byte[] AAD)
+      throws IOException {
     return read(from, new BloomFilterHeader(), decryptor, AAD);
   }
 
-  public static void writeBloomFilterHeader(BloomFilterHeader header, OutputStream out,
-      BlockCipher.Encryptor encryptor, byte[] AAD) throws IOException {
+  public static void writeBloomFilterHeader(
+      BloomFilterHeader header, OutputStream out, BlockCipher.Encryptor encryptor, byte[] AAD)
+      throws IOException {
     write(header, out, encryptor, AAD);
   }
 
@@ -118,8 +119,8 @@ public class Util {
     writePageHeader(pageHeader, to, null, null);
   }
 
-  public static void writePageHeader(PageHeader pageHeader, OutputStream to, 
-      BlockCipher.Encryptor encryptor, byte[] AAD) throws IOException {
+  public static void writePageHeader(
+      PageHeader pageHeader, OutputStream to, BlockCipher.Encryptor encryptor, byte[] AAD) throws IOException {
     write(pageHeader, to, encryptor, AAD);
   }
 
@@ -127,18 +128,22 @@ public class Util {
     return readPageHeader(from, null, null);
   }
 
-  public static PageHeader readPageHeader(InputStream from, 
-      BlockCipher.Decryptor decryptor, byte[] AAD) throws IOException {
+  public static PageHeader readPageHeader(InputStream from, BlockCipher.Decryptor decryptor, byte[] AAD)
+      throws IOException {
     return MetadataValidator.validate(read(from, new PageHeader(), decryptor, AAD));
   }
 
-  public static void writeFileMetaData(org.apache.parquet.format.FileMetaData fileMetadata, 
-      OutputStream to) throws IOException {
+  public static void writeFileMetaData(org.apache.parquet.format.FileMetaData fileMetadata, OutputStream to)
+      throws IOException {
     writeFileMetaData(fileMetadata, to, null, null);
   }
 
-  public static void writeFileMetaData(org.apache.parquet.format.FileMetaData fileMetadata, 
-      OutputStream to, BlockCipher.Encryptor encryptor, byte[] AAD) throws IOException {
+  public static void writeFileMetaData(
+      org.apache.parquet.format.FileMetaData fileMetadata,
+      OutputStream to,
+      BlockCipher.Encryptor encryptor,
+      byte[] AAD)
+      throws IOException {
     write(fileMetadata, to, encryptor, AAD);
   }
 
@@ -146,24 +151,26 @@ public class Util {
     return readFileMetaData(from, null, null);
   }
 
-  public static FileMetaData readFileMetaData(InputStream from, 
-      BlockCipher.Decryptor decryptor, byte[] AAD) throws IOException {
+  public static FileMetaData readFileMetaData(InputStream from, BlockCipher.Decryptor decryptor, byte[] AAD)
+      throws IOException {
     return read(from, new FileMetaData(), decryptor, AAD);
   }
 
-  public static void writeColumnMetaData(ColumnMetaData columnMetaData, OutputStream to, 
-      BlockCipher.Encryptor encryptor, byte[] AAD) throws IOException {
+  public static void writeColumnMetaData(
+      ColumnMetaData columnMetaData, OutputStream to, BlockCipher.Encryptor encryptor, byte[] AAD)
+      throws IOException {
     write(columnMetaData, to, encryptor, AAD);
   }
 
-  public static ColumnMetaData readColumnMetaData(InputStream from, 
-      BlockCipher.Decryptor decryptor, byte[] AAD) throws IOException {
+  public static ColumnMetaData readColumnMetaData(InputStream from, BlockCipher.Decryptor decryptor, byte[] AAD)
+      throws IOException {
     return read(from, new ColumnMetaData(), decryptor, AAD);
   }
 
   /**
    * reads the meta data from the stream
-   * @param from the stream to read the metadata from
+   *
+   * @param from          the stream to read the metadata from
    * @param skipRowGroups whether row groups should be skipped
    * @return the resulting metadata
    * @throws IOException if any I/O error occurs during the reading
@@ -172,8 +179,8 @@ public class Util {
     return readFileMetaData(from, skipRowGroups, (BlockCipher.Decryptor) null, (byte[]) null);
   }
 
-  public static FileMetaData readFileMetaData(InputStream from, boolean skipRowGroups, 
-      BlockCipher.Decryptor decryptor, byte[] AAD) throws IOException {
+  public static FileMetaData readFileMetaData(
+      InputStream from, boolean skipRowGroups, BlockCipher.Decryptor decryptor, byte[] AAD) throws IOException {
     FileMetaData md = new FileMetaData();
     if (skipRowGroups) {
       readFileMetaData(from, new DefaultFileMetaDataConsumer(md), skipRowGroups, decryptor, AAD);
@@ -183,7 +190,8 @@ public class Util {
     return md;
   }
 
-  public static void writeFileCryptoMetaData(org.apache.parquet.format.FileCryptoMetaData cryptoMetadata, OutputStream to) throws IOException { 
+  public static void writeFileCryptoMetaData(
+      org.apache.parquet.format.FileCryptoMetaData cryptoMetadata, OutputStream to) throws IOException {
     write(cryptoMetadata, to, null, null);
   }
 
@@ -193,22 +201,27 @@ public class Util {
 
   /**
    * To read metadata in a streaming fashion.
-   *
    */
-  public static abstract class FileMetaDataConsumer {
-    abstract public void setVersion(int version);
-    abstract public void setSchema(List<SchemaElement> schema);
-    abstract public void setNumRows(long numRows);
-    abstract public void addRowGroup(RowGroup rowGroup);
-    abstract public void addKeyValueMetaData(KeyValue kv);
-    abstract public void setCreatedBy(String createdBy);
-    abstract public void setEncryptionAlgorithm(EncryptionAlgorithm encryptionAlgorithm);
-    abstract public void setFooterSigningKeyMetadata(byte[] footerSigningKeyMetadata);
+  public abstract static class FileMetaDataConsumer {
+    public abstract void setVersion(int version);
+
+    public abstract void setSchema(List<SchemaElement> schema);
+
+    public abstract void setNumRows(long numRows);
+
+    public abstract void addRowGroup(RowGroup rowGroup);
+
+    public abstract void addKeyValueMetaData(KeyValue kv);
+
+    public abstract void setCreatedBy(String createdBy);
+
+    public abstract void setEncryptionAlgorithm(EncryptionAlgorithm encryptionAlgorithm);
+
+    public abstract void setFooterSigningKeyMetadata(byte[] footerSigningKeyMetadata);
   }
 
   /**
    * Simple default consumer that sets the fields
-   *
    */
   public static final class DefaultFileMetaDataConsumer extends FileMetaDataConsumer {
     private final FileMetaData md;
@@ -262,17 +275,24 @@ public class Util {
     readFileMetaData(from, consumer, null, null);
   }
 
-  public static void readFileMetaData(InputStream from, FileMetaDataConsumer consumer, 
-      BlockCipher.Decryptor decryptor, byte[] AAD) throws IOException {
+  public static void readFileMetaData(
+      InputStream from, FileMetaDataConsumer consumer, BlockCipher.Decryptor decryptor, byte[] AAD)
+      throws IOException {
     readFileMetaData(from, consumer, false, decryptor, AAD);
   }
 
-  public static void readFileMetaData(InputStream from, final FileMetaDataConsumer consumer, boolean skipRowGroups) throws IOException {
+  public static void readFileMetaData(InputStream from, final FileMetaDataConsumer consumer, boolean skipRowGroups)
+      throws IOException {
     readFileMetaData(from, consumer, skipRowGroups, null, null);
   }
 
-  public static void readFileMetaData(final InputStream input, final FileMetaDataConsumer consumer, 
-      boolean skipRowGroups, BlockCipher.Decryptor decryptor, byte[] AAD) throws IOException {
+  public static void readFileMetaData(
+      final InputStream input,
+      final FileMetaDataConsumer consumer,
+      boolean skipRowGroups,
+      BlockCipher.Decryptor decryptor,
+      byte[] AAD)
+      throws IOException {
     try {
       DelegatingFieldConsumer eventConsumer = fieldConsumer()
           .onField(VERSION, new I32Consumer() {
@@ -280,32 +300,40 @@ public class Util {
             public void consume(int value) {
               consumer.setVersion(value);
             }
-          }).onField(SCHEMA, listOf(SchemaElement.class, new Consumer<List<SchemaElement>>() {
+          })
+          .onField(SCHEMA, listOf(SchemaElement.class, new Consumer<List<SchemaElement>>() {
             @Override
             public void consume(List<SchemaElement> schema) {
               consumer.setSchema(schema);
             }
-          })).onField(NUM_ROWS, new I64Consumer() {
+          }))
+          .onField(NUM_ROWS, new I64Consumer() {
             @Override
             public void consume(long value) {
               consumer.setNumRows(value);
             }
-          }).onField(KEY_VALUE_METADATA, listElementsOf(struct(KeyValue.class, new Consumer<KeyValue>() {
+          })
+          .onField(KEY_VALUE_METADATA, listElementsOf(struct(KeyValue.class, new Consumer<KeyValue>() {
             @Override
             public void consume(KeyValue kv) {
               consumer.addKeyValueMetaData(kv);
             }
-          }))).onField(CREATED_BY, new StringConsumer() {
+          })))
+          .onField(CREATED_BY, new StringConsumer() {
             @Override
             public void consume(String value) {
               consumer.setCreatedBy(value);
             }
-          }).onField(ENCRYPTION_ALGORITHM, struct(EncryptionAlgorithm.class, new Consumer<EncryptionAlgorithm>() {
-            @Override
-            public void consume(EncryptionAlgorithm encryptionAlgorithm) {
-              consumer.setEncryptionAlgorithm(encryptionAlgorithm);
-            }
-          })).onField(FOOTER_SIGNING_KEY_METADATA, new StringConsumer() {
+          })
+          .onField(
+              ENCRYPTION_ALGORITHM,
+              struct(EncryptionAlgorithm.class, new Consumer<EncryptionAlgorithm>() {
+                @Override
+                public void consume(EncryptionAlgorithm encryptionAlgorithm) {
+                  consumer.setEncryptionAlgorithm(encryptionAlgorithm);
+                }
+              }))
+          .onField(FOOTER_SIGNING_KEY_METADATA, new StringConsumer() {
             @Override
             public void consume(String value) {
               byte[] keyMetadata = value.getBytes(StandardCharsets.UTF_8);
@@ -314,20 +342,20 @@ public class Util {
           });
 
       if (!skipRowGroups) {
-        eventConsumer = eventConsumer.onField(ROW_GROUPS, listElementsOf(struct(RowGroup.class, new Consumer<RowGroup>() {
-          @Override
-          public void consume(RowGroup rowGroup) {
-            consumer.addRowGroup(rowGroup);
-          }
-        })));
+        eventConsumer = eventConsumer.onField(
+            ROW_GROUPS, listElementsOf(struct(RowGroup.class, new Consumer<RowGroup>() {
+              @Override
+              public void consume(RowGroup rowGroup) {
+                consumer.addRowGroup(rowGroup);
+              }
+            })));
       }
 
       final InputStream from;
       if (null == decryptor) {
         from = input;
-      }
-      else {
-        byte[] plainText =  decryptor.decrypt(input, AAD);
+      } else {
+        byte[] plainText = decryptor.decrypt(input, AAD);
         from = new ByteArrayInputStream(plainText);
       }
       new EventBasedThriftReader(protocol(from)).readStruct(eventConsumer);
@@ -336,11 +364,11 @@ public class Util {
     }
   }
 
-  private static TProtocol protocol(OutputStream to) {
+  private static TProtocol protocol(OutputStream to) throws TTransportException {
     return protocol(new TIOStreamTransport(to));
   }
 
-  private static TProtocol protocol(InputStream from) {
+  private static TProtocol protocol(InputStream from) throws TTransportException {
     return protocol(new TIOStreamTransport(from));
   }
 
@@ -348,8 +376,8 @@ public class Util {
     return new InterningProtocol(new TCompactProtocol(t));
   }
 
-
-  private static <T extends TBase<?,?>> T read(final InputStream input, T tbase, BlockCipher.Decryptor decryptor, byte[] AAD) throws IOException {
+  private static <T extends TBase<?, ?>> T read(
+      final InputStream input, T tbase, BlockCipher.Decryptor decryptor, byte[] AAD) throws IOException {
     final InputStream from;
     if (null == decryptor) {
       from = input;
@@ -366,8 +394,9 @@ public class Util {
     }
   }
 
-  private static void write(TBase<?, ?> tbase, OutputStream to, BlockCipher.Encryptor encryptor, byte[] AAD) throws IOException {
-    if (null == encryptor) { 
+  private static void write(TBase<?, ?> tbase, OutputStream to, BlockCipher.Encryptor encryptor, byte[] AAD)
+      throws IOException {
+    if (null == encryptor) {
       try {
         tbase.write(protocol(to));
         return;
@@ -385,4 +414,3 @@ public class Util {
     }
   }
 }
-
