@@ -23,7 +23,9 @@ import static org.junit.Assert.assertEquals;
 import java.io.File;
 import java.io.IOException;
 import java.util.ArrayList;
+import java.util.HashMap;
 import java.util.List;
+import java.util.Map;
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.fs.Path;
 import org.apache.parquet.bytes.ByteBufferAllocator;
@@ -54,6 +56,12 @@ public class PhoneBookWriter {
       + "      optional binary kind (UTF8);\n"
       + "    }\n"
       + "  }\n"
+      + "  optional group accounts (MAP) {\n"
+      + "    repeated group key_value {\n"
+      + "      required binary key;\n"
+      + "      required double value;\n"
+      + "    }\n"
+      + "  }\n"
       + "}\n";
 
   private static final MessageType schema = getSchema();
@@ -154,11 +162,19 @@ public class PhoneBookWriter {
     private final List<PhoneNumber> phoneNumbers;
     private final Location location;
 
+    private final Map<String, Double> accounts;
+
     public User(long id, String name, List<PhoneNumber> phoneNumbers, Location location) {
+      this(id, name, phoneNumbers, location, null);
+    }
+
+    public User(
+        long id, String name, List<PhoneNumber> phoneNumbers, Location location, Map<String, Double> accounts) {
       this.id = id;
       this.name = name;
       this.phoneNumbers = phoneNumbers;
       this.location = location;
+      this.accounts = accounts;
     }
 
     public long getId() {
@@ -177,6 +193,10 @@ public class PhoneBookWriter {
       return location;
     }
 
+    public Map<String, Double> getAccounts() {
+      return accounts;
+    }
+
     @Override
     public boolean equals(Object o) {
       if (this == o) return true;
@@ -189,6 +209,7 @@ public class PhoneBookWriter {
       if (name != null ? !name.equals(user.name) : user.name != null) return false;
       if (phoneNumbers != null ? !phoneNumbers.equals(user.phoneNumbers) : user.phoneNumbers != null)
         return false;
+      if (accounts != null ? !accounts.equals(user.accounts) : user.accounts != null) return false;
 
       return true;
     }
@@ -199,17 +220,18 @@ public class PhoneBookWriter {
       result = 31 * result + (name != null ? name.hashCode() : 0);
       result = 31 * result + (phoneNumbers != null ? phoneNumbers.hashCode() : 0);
       result = 31 * result + (location != null ? location.hashCode() : 0);
+      result = 31 * result + (accounts != null ? accounts.hashCode() : 0);
       return result;
     }
 
     @Override
     public String toString() {
       return "User [id=" + id + ", name=" + name + ", phoneNumbers=" + phoneNumbers + ", location=" + location
-          + "]";
+          + ", accounts=" + accounts + "]";
     }
 
     public User cloneWithName(String name) {
-      return new User(id, name, phoneNumbers, location);
+      return new User(id, name, phoneNumbers, location, accounts);
     }
   }
 
@@ -241,6 +263,16 @@ public class PhoneBookWriter {
         location.append("lat", user.getLocation().getLat());
       }
     }
+
+    if (user.getAccounts() != null) {
+      Group accounts = root.addGroup("accounts");
+      for (Map.Entry<String, Double> account : user.getAccounts().entrySet()) {
+        Group kv = accounts.addGroup("key_value");
+        kv.append("key", account.getKey());
+        kv.append("value", account.getValue());
+      }
+    }
+
     return root;
   }
 
@@ -249,7 +281,8 @@ public class PhoneBookWriter {
         getLong(root, "id"),
         getString(root, "name"),
         getPhoneNumbers(getGroup(root, "phoneNumbers")),
-        getLocation(getGroup(root, "location")));
+        getLocation(getGroup(root, "location")),
+        getAccounts(getGroup(root, "accounts")));
   }
 
   private static List<PhoneNumber> getPhoneNumbers(Group phoneNumbers) {
@@ -271,6 +304,19 @@ public class PhoneBookWriter {
     return new Location(getDouble(location, "lon"), getDouble(location, "lat"));
   }
 
+  private static Map<String, Double> getAccounts(Group accounts) {
+    if (accounts == null) {
+      return null;
+    }
+    Map<String, Double> map = new HashMap<>();
+    for (int i = 0, n = accounts.getFieldRepetitionCount("key_value"); i < n; ++i) {
+      Group kv = accounts.getGroup("key_value", i);
+
+      map.put(getString(kv, "key"), getDouble(kv, "value"));
+    }
+    return map;
+  }
+
   private static boolean isNull(Group group, String field) {
     // Use null value if the field is not in the group schema
     if (!group.getType().containsField(field)) {
@@ -336,6 +382,10 @@ public class PhoneBookWriter {
         .withConf(conf)
         .withFilter(filter)
         .withAllocator(allocator)
+        .useBloomFilter(false)
+        .useDictionaryFilter(false)
+        .useStatsFilter(false)
+        .useColumnIndexFilter(false)
         .build();
   }
 
