@@ -19,11 +19,6 @@
 package org.apache.parquet.hadoop;
 
 import static java.util.Collections.unmodifiableMap;
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertTrue;
-import static org.junit.Assert.fail;
-import static org.mockito.Mockito.mock;
 import static org.apache.parquet.column.Encoding.BIT_PACKED;
 import static org.apache.parquet.column.Encoding.PLAIN;
 import static org.apache.parquet.filter2.predicate.FilterApi.and;
@@ -32,7 +27,13 @@ import static org.apache.parquet.filter2.predicate.FilterApi.intColumn;
 import static org.apache.parquet.filter2.predicate.FilterApi.not;
 import static org.apache.parquet.filter2.predicate.FilterApi.notEq;
 import static org.apache.parquet.filter2.predicate.FilterApi.or;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.fail;
+import static org.mockito.Mockito.mock;
 
+import com.google.common.io.Files;
 import java.io.File;
 import java.io.IOException;
 import java.util.ArrayList;
@@ -41,16 +42,12 @@ import java.util.HashMap;
 import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
-
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.fs.BlockLocation;
 import org.apache.hadoop.fs.FileStatus;
 import org.apache.hadoop.fs.FileSystem;
 import org.apache.hadoop.fs.Path;
 import org.apache.hadoop.mapreduce.Job;
-import org.junit.Before;
-import org.junit.Test;
-
 import org.apache.hadoop.mapreduce.lib.input.FileInputFormat;
 import org.apache.parquet.bytes.BytesInput;
 import org.apache.parquet.column.ColumnDescriptor;
@@ -75,8 +72,8 @@ import org.apache.parquet.io.ParquetDecodingException;
 import org.apache.parquet.schema.MessageType;
 import org.apache.parquet.schema.MessageTypeParser;
 import org.apache.parquet.schema.PrimitiveType.PrimitiveTypeName;
-
-import com.google.common.io.Files;
+import org.junit.Before;
+import org.junit.Test;
 
 public class TestInputFormat {
 
@@ -87,11 +84,11 @@ public class TestInputFormat {
   FileMetaData fileMetaData;
 
   /*
-    The test File contains 2-3 hdfs blocks based on the setting of each test, when hdfsBlock size is set to 50: [0-49][50-99]
-    each row group is of size 10, so the rowGroups layout on hdfs is like:
-    xxxxx xxxxx
-    each x is a row group, each groups of x's is a hdfsBlock
-   */
+  The test File contains 2-3 hdfs blocks based on the setting of each test, when hdfsBlock size is set to 50: [0-49][50-99]
+  each row group is of size 10, so the rowGroups layout on hdfs is like:
+  xxxxx xxxxx
+  each x is a row group, each groups of x's is a hdfsBlock
+  */
   @Before
   public void setUp() {
     blocks = new ArrayList<BlockMetaData>();
@@ -108,8 +105,9 @@ public class TestInputFormat {
       generateSplitByMinMaxSize(50, 49);
       fail("should throw exception when max split size is smaller than the min split size");
     } catch (ParquetDecodingException e) {
-      assertEquals("maxSplitSize and minSplitSize should be positive and max should be greater or equal to the minSplitSize: maxSplitSize = 49; minSplitSize is 50"
-              , e.getMessage());
+      assertEquals(
+          "maxSplitSize and minSplitSize should be positive and max should be greater or equal to the minSplitSize: maxSplitSize = 49; minSplitSize is 50",
+          e.getMessage());
     }
   }
 
@@ -119,8 +117,9 @@ public class TestInputFormat {
       generateSplitByMinMaxSize(-100, -50);
       fail("should throw exception when max split size is negative");
     } catch (ParquetDecodingException e) {
-      assertEquals("maxSplitSize and minSplitSize should be positive and max should be greater or equal to the minSplitSize: maxSplitSize = -50; minSplitSize is -100"
-              , e.getMessage());
+      assertEquals(
+          "maxSplitSize and minSplitSize should be positive and max should be greater or equal to the minSplitSize: maxSplitSize = -50; minSplitSize is -100",
+          e.getMessage());
     }
   }
 
@@ -138,14 +137,15 @@ public class TestInputFormat {
     ParquetInputFormat.setFilterPredicate(conf, not(p));
     read = ParquetInputFormat.getFilter(conf);
     assertTrue(read instanceof FilterPredicateCompat);
-    assertEquals(and(notEq(intColumn, 7), notEq(intColumn, 12)), ((FilterPredicateCompat) read).getFilterPredicate());
+    assertEquals(
+        and(notEq(intColumn, 7), notEq(intColumn, 12)), ((FilterPredicateCompat) read).getFilterPredicate());
 
     assertEquals(FilterCompat.NOOP, ParquetInputFormat.getFilter(new Configuration()));
   }
 
   /*
-    aaaaa bbbbb
-   */
+  aaaaa bbbbb
+  */
   @Test
   public void testGenerateSplitsAlignedWithHDFSBlock() throws IOException {
     withHDFSBlockSize(50, 50);
@@ -158,19 +158,21 @@ public class TestInputFormat {
     shouldSplitBlockSizeBe(splits, 5, 5);
     shouldSplitLocationBe(splits, 0, 1);
     shouldSplitLengthBe(splits, 50, 50);
-
   }
 
   @Test
   public void testRowGroupNotAlignToHDFSBlock() throws IOException {
-    //Test HDFS blocks size(51) is not multiple of row group size(10)
+    // Test HDFS blocks size(51) is not multiple of row group size(10)
     withHDFSBlockSize(51, 51);
     List<ParquetInputSplit> splits = generateSplitByMinMaxSize(50, 50);
     shouldSplitBlockSizeBe(splits, 5, 5);
-    shouldSplitLocationBe(splits, 0, 0);//for the second split, the first byte will still be in the first hdfs block, therefore the locations are both 0
+    shouldSplitLocationBe(
+        splits, 0,
+        0); // for the second split, the first byte will still be in the first hdfs block, therefore the
+    // locations are both 0
     shouldSplitLengthBe(splits, 50, 50);
 
-    //Test a rowgroup is greater than the hdfsBlock boundary
+    // Test a rowgroup is greater than the hdfsBlock boundary
     withHDFSBlockSize(49, 49);
     splits = generateSplitByMinMaxSize(50, 50);
     shouldSplitBlockSizeBe(splits, 5, 5);
@@ -183,7 +185,7 @@ public class TestInputFormat {
     for 9th group, the mid point is 85, the end of second block is 88, so it's considered mainly in the 2nd hdfs block, and therefore inserted as
     a row group of split b
      */
-    withHDFSBlockSize(44,44,44);
+    withHDFSBlockSize(44, 44, 44);
     splits = generateSplitByMinMaxSize(40, 50);
     shouldSplitBlockSizeBe(splits, 4, 5, 1);
     shouldSplitLocationBe(splits, 0, 0, 2);
@@ -191,9 +193,9 @@ public class TestInputFormat {
   }
 
   /*
-    when min size is 55, max size is 56, the first split will be generated with 6 row groups(size of 10 each), which satisfies split.size>min.size, but not split.size<max.size
-    aaaaa abbbb
-   */
+  when min size is 55, max size is 56, the first split will be generated with 6 row groups(size of 10 each), which satisfies split.size>min.size, but not split.size<max.size
+  aaaaa abbbb
+  */
   @Test
   public void testGenerateSplitsNotAlignedWithHDFSBlock() throws IOException, InterruptedException {
     withHDFSBlockSize(50, 50);
@@ -205,7 +207,10 @@ public class TestInputFormat {
     withHDFSBlockSize(51, 51);
     splits = generateSplitByMinMaxSize(55, 56);
     shouldSplitBlockSizeBe(splits, 6, 4);
-    shouldSplitLocationBe(splits, 0, 1);//since a whole row group of split a is added to the second hdfs block, so the location of split b is still 1
+    shouldSplitLocationBe(
+        splits, 0,
+        1); // since a whole row group of split a is added to the second hdfs block, so the location of split b
+    // is still 1
     shouldSplitLengthBe(splits, 60, 40);
 
     withHDFSBlockSize(49, 49, 49);
@@ -213,14 +218,13 @@ public class TestInputFormat {
     shouldSplitBlockSizeBe(splits, 6, 4);
     shouldSplitLocationBe(splits, 0, 1);
     shouldSplitLengthBe(splits, 60, 40);
-
   }
 
   /*
-    when the max size is set to be 30, first split will be of size 30,
-    and when creating second split, it will try to align it to second hdfsBlock, and therefore generates a split of size 20
-    aaabb cccdd
-   */
+  when the max size is set to be 30, first split will be of size 30,
+  and when creating second split, it will try to align it to second hdfsBlock, and therefore generates a split of size 20
+  aaabb cccdd
+  */
   @Test
   public void testGenerateSplitsSmallerThanMaxSizeAndAlignToHDFS() throws Exception {
     withHDFSBlockSize(50, 50);
@@ -231,11 +235,11 @@ public class TestInputFormat {
 
     /*
     aaabb cccdd
-         */
+    */
     withHDFSBlockSize(51, 51);
     splits = generateSplitByMinMaxSize(18, 30);
     shouldSplitBlockSizeBe(splits, 3, 2, 3, 2);
-    shouldSplitLocationBe(splits, 0, 0, 0, 1);//the first byte of split c is in the first hdfs block
+    shouldSplitLocationBe(splits, 0, 0, 0, 1); // the first byte of split c is in the first hdfs block
     shouldSplitLengthBe(splits, 30, 20, 30, 20);
 
     /*
@@ -249,9 +253,9 @@ public class TestInputFormat {
   }
 
   /*
-    when the min size is set to be 25, so the second split can not be aligned with the boundary of hdfs block, there for split of size 30 will be created as the 3rd split.
-    aaabb bcccd
-   */
+  when the min size is set to be 25, so the second split can not be aligned with the boundary of hdfs block, there for split of size 30 will be created as the 3rd split.
+  aaabb bcccd
+  */
   @Test
   public void testGenerateSplitsCrossHDFSBlockBoundaryToSatisfyMinSize() throws Exception {
     withHDFSBlockSize(50, 50);
@@ -262,9 +266,9 @@ public class TestInputFormat {
   }
 
   /*
-    when rowGroups size is 10, but min split size is 10, max split size is 18, it will create splits of size 20 and of size 10 and align with hdfsBlocks
-    aabbc ddeef
-   */
+  when rowGroups size is 10, but min split size is 10, max split size is 18, it will create splits of size 20 and of size 10 and align with hdfsBlocks
+  aabbc ddeef
+  */
   @Test
   public void testMultipleRowGroupsInABlockToAlignHDFSBlock() throws Exception {
     withHDFSBlockSize(50, 50);
@@ -282,7 +286,9 @@ public class TestInputFormat {
     withHDFSBlockSize(51, 51);
     splits = generateSplitByMinMaxSize(10, 18);
     shouldSplitBlockSizeBe(splits, 2, 2, 1, 2, 2, 1);
-    shouldSplitLocationBe(splits, 0, 0, 0, 0, 1, 1);// location of split d should be 0, since the first byte is in the first hdfs block
+    shouldSplitLocationBe(
+        splits, 0, 0, 0, 0, 1,
+        1); // location of split d should be 0, since the first byte is in the first hdfs block
     shouldSplitLengthBe(splits, 20, 20, 10, 20, 20, 10);
 
     /*
@@ -329,18 +335,22 @@ public class TestInputFormat {
     } catch (IllegalArgumentException e) {
       assertEquals("You cannot provide an UnboundRecordFilter after providing a FilterPredicate", e.getMessage());
     }
-
   }
 
   public static BlockMetaData makeBlockFromStats(IntStatistics stats, long valueCount) {
     BlockMetaData blockMetaData = new BlockMetaData();
 
-    ColumnChunkMetaData column = ColumnChunkMetaData.get(ColumnPath.get("foo"),
+    ColumnChunkMetaData column = ColumnChunkMetaData.get(
+        ColumnPath.get("foo"),
         PrimitiveTypeName.INT32,
         CompressionCodecName.GZIP,
         new HashSet<Encoding>(Arrays.asList(Encoding.PLAIN)),
         stats,
-        100l, 100l, valueCount, 100l, 100l);
+        100l,
+        100l,
+        valueCount,
+        100l,
+        100l);
     blockMetaData.addColumn(column);
     blockMetaData.setTotalByteSize(200l);
     blockMetaData.setRowCount(valueCount);
@@ -354,7 +364,8 @@ public class TestInputFormat {
     ParquetInputFormat.FootersCacheValue cacheValue = getDummyCacheValue(tempFile, fs);
 
     assertTrue(tempFile.setLastModified(tempFile.lastModified() + 5000));
-    assertFalse(cacheValue.isCurrent(new ParquetInputFormat.FileStatusWrapper(fs.getFileStatus(new Path(tempFile.getAbsolutePath())))));
+    assertFalse(cacheValue.isCurrent(
+        new ParquetInputFormat.FileStatusWrapper(fs.getFileStatus(new Path(tempFile.getAbsolutePath())))));
   }
 
   @Test
@@ -389,7 +400,9 @@ public class TestInputFormat {
   public void testGetFootersReturnsInPredictableOrder() throws IOException {
     File tempDir = Files.createTempDir();
     tempDir.deleteOnExit();
-    int numFiles = 10; // create a nontrivial number of files so that it actually tests getFooters() returns files in the correct order
+    int numFiles =
+        10; // create a nontrivial number of files so that it actually tests getFooters() returns files in the
+    // correct order
 
     Path[] paths = new Path[numFiles];
     for (int i = 0; i < numFiles; i++) {
@@ -416,8 +429,8 @@ public class TestInputFormat {
     String[] columnPath = {"a", "b"};
     ColumnDescriptor c1 = schema.getColumnDescription(columnPath);
 
-    byte[] bytes1 = { 0, 1, 2, 3};
-    byte[] bytes2 = { 2, 3, 4, 5};
+    byte[] bytes1 = {0, 1, 2, 3};
+    byte[] bytes2 = {2, 3, 4, 5};
     CompressionCodecName codec = CompressionCodecName.UNCOMPRESSED;
 
     BinaryStatistics stats = new BinaryStatistics();
@@ -450,12 +463,13 @@ public class TestInputFormat {
     ParquetInputFormat.FileStatusWrapper statusWrapper = new ParquetInputFormat.FileStatusWrapper(status);
     ParquetMetadata mockMetadata = mock(ParquetMetadata.class);
     ParquetInputFormat.FootersCacheValue cacheValue =
-            new ParquetInputFormat.FootersCacheValue(statusWrapper, new Footer(path, mockMetadata));
+        new ParquetInputFormat.FootersCacheValue(statusWrapper, new Footer(path, mockMetadata));
     assertTrue(cacheValue.isCurrent(statusWrapper));
     return cacheValue;
   }
 
   private static final Map<String, String> extramd;
+
   static {
     Map<String, String> md = new HashMap<String, String>();
     md.put("specific", "foo");
@@ -464,23 +478,25 @@ public class TestInputFormat {
 
   private List<ParquetInputSplit> generateSplitByMinMaxSize(long min, long max) throws IOException {
     return ClientSideMetadataSplitStrategy.generateSplits(
-        blocks, hdfsBlocks,
-        fileStatus,
-        schema.toString(),
-        extramd,
-        min, max);
+        blocks, hdfsBlocks, fileStatus, schema.toString(), extramd, min, max);
   }
 
-  private List<ParquetInputSplit> generateSplitByDeprecatedConstructor(long min, long max) throws
-      IOException {
+  private List<ParquetInputSplit> generateSplitByDeprecatedConstructor(long min, long max) throws IOException {
     List<ParquetInputSplit> splits = new ArrayList<ParquetInputSplit>();
-    List<ClientSideMetadataSplitStrategy.SplitInfo> splitInfos = ClientSideMetadataSplitStrategy
-        .generateSplitInfo(blocks, hdfsBlocks, min, max);
+    List<ClientSideMetadataSplitStrategy.SplitInfo> splitInfos =
+        ClientSideMetadataSplitStrategy.generateSplitInfo(blocks, hdfsBlocks, min, max);
 
     for (ClientSideMetadataSplitStrategy.SplitInfo splitInfo : splitInfos) {
-      ParquetInputSplit split = new ParquetInputSplit(fileStatus.getPath(),
-          splitInfo.hdfsBlock.getOffset(), splitInfo.hdfsBlock.getLength(), splitInfo.hdfsBlock.getHosts(),
-          splitInfo.rowGroups, schema.toString(), null, null, extramd);
+      ParquetInputSplit split = new ParquetInputSplit(
+          fileStatus.getPath(),
+          splitInfo.hdfsBlock.getOffset(),
+          splitInfo.hdfsBlock.getLength(),
+          splitInfo.hdfsBlock.getHosts(),
+          splitInfo.rowGroups,
+          schema.toString(),
+          null,
+          null,
+          extramd);
       splits.add(split);
     }
 
@@ -506,7 +522,10 @@ public class TestInputFormat {
     for (int i = 0; i < locations.length; i++) {
       int loc = locations[i];
       ParquetInputSplit split = splits.get(i);
-      assertEquals(message(splits) + i, "[foo" + loc + ".datanode, bar" + loc + ".datanode]", Arrays.toString(split.getLocations()));
+      assertEquals(
+          message(splits) + i,
+          "[foo" + loc + ".datanode, bar" + loc + ".datanode]",
+          Arrays.toString(split.getLocations()));
     }
   }
 
@@ -533,7 +552,8 @@ public class TestInputFormat {
     long offset = 0;
     for (int i = 0; i < blockSizes.length; i++) {
       long blockSize = blockSizes[i];
-      hdfsBlocks[i] = new BlockLocation(new String[0], new String[]{"foo" + i + ".datanode", "bar" + i + ".datanode"}, offset, blockSize);
+      hdfsBlocks[i] = new BlockLocation(
+          new String[0], new String[] {"foo" + i + ".datanode", "bar" + i + ".datanode"}, offset, blockSize);
       offset += blockSize;
     }
     fileStatus = new FileStatus(offset, false, 2, 50, 0, new Path("hdfs://foo.namenode:1234/bar"));
@@ -541,13 +561,18 @@ public class TestInputFormat {
 
   private BlockMetaData newBlock(long start, long compressedBlockSize) {
     BlockMetaData blockMetaData = new BlockMetaData();
-    long uncompressedSize = compressedBlockSize * 2;//assuming the compression ratio is 2
-    ColumnChunkMetaData column = ColumnChunkMetaData.get(ColumnPath.get("foo"),
-                                                         PrimitiveTypeName.BINARY,
-                                                         CompressionCodecName.GZIP,
-                                                         new HashSet<Encoding>(Arrays.asList(Encoding.PLAIN)),
-                                                         new BinaryStatistics(),
-                                                         start, 0l, 0l, compressedBlockSize, uncompressedSize);
+    long uncompressedSize = compressedBlockSize * 2; // assuming the compression ratio is 2
+    ColumnChunkMetaData column = ColumnChunkMetaData.get(
+        ColumnPath.get("foo"),
+        PrimitiveTypeName.BINARY,
+        CompressionCodecName.GZIP,
+        new HashSet<Encoding>(Arrays.asList(Encoding.PLAIN)),
+        new BinaryStatistics(),
+        start,
+        0l,
+        0l,
+        compressedBlockSize,
+        uncompressedSize);
     blockMetaData.addColumn(column);
     blockMetaData.setTotalByteSize(uncompressedSize);
     return blockMetaData;
