@@ -1,4 +1,4 @@
-/* 
+/*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -6,9 +6,9 @@
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
+ *
  *   http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
@@ -21,12 +21,12 @@ package org.apache.parquet.pig.convert;
 /**
  * for converters to add their current value to their parent
  */
-abstract public class ParentValueContainer {
+public abstract class ParentValueContainer {
 
   /**
    * will add the value to the parent whether it's a map, a bag or a tuple
+   *
    * @param value
    */
   abstract void add(Object value);
-
 }
